==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/StochRSIIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StochRSIIndicatorStrategy } from "./StochRSIIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let StochRSIIndicator = /*@__PURE__*/ (() => {
    class StochRSIIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new StochRSIIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return StochRSIIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(StochRSIIndicator.u7));
        }
        set u6(a) {
            this.h(StochRSIIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    StochRSIIndicator.$t = /*@__PURE__*/ markType(StochRSIIndicator, 'StochRSIIndicator', StrategyBasedIndicator.$);
    StochRSIIndicator.u7 = /*@__PURE__*/ StrategyBasedIndicator.u3(14, StochRSIIndicator.$);
    return StochRSIIndicator;
})();

==> igniteui-react-charts-18.2.0.tgz: package/esm2015/lib/StochRSIIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { StochRSIIndicatorStrategy } from "./StochRSIIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let StochRSIIndicator = /*@__PURE__*/ (() => {
    class StochRSIIndicator extends StrategyBasedIndicator {
        get_up() {
            return new StochRSIIndicatorStrategy();
        }
        get up() {
            return this.get_up();
        }
        get_u2() {
            return StochRSIIndicator.$;
        }
        get u2() {
            return this.get_u2();
        }
        get va() {
            return typeGetValue(this.c(StochRSIIndicator.vb));
        }
        set va(a) {
            this.h(StochRSIIndicator.vb, a);
        }
        uv() {
            return this.va;
        }
        u4(a) {
            this.va = a;
        }
    }
    StochRSIIndicator.$t = /*@__PURE__*/ markType(StochRSIIndicator, 'StochRSIIndicator', StrategyBasedIndicator.$);
    StochRSIIndicator.vb = /*@__PURE__*/ StrategyBasedIndicator.u7(14, StochRSIIndicator.$);
    return StochRSIIndicator;
})();
